@@ -145,6 +145,23 @@ namespace TagLib {
 			set {}
 		}
 		
+		/// <summary>
+		///    Gets and sets the sort name for the title of the media 
+		///    described by the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> object containing the sort name for
+		///    the title of the media described by the current instance or <see
+		///    langword="null" /> if no value is present.
+		/// </value>
+		/// <remarks>
+		///    Possibly used to sort compilations, or episodic content.
+		/// </remarks>
+		public virtual string TitleSort {
+			get {return null;}
+			set {}
+		}
+		
 		/// <summary>
 		///    Gets and sets the performers or artists who performed in
 		///    the media described by the current instance.
@@ -173,6 +190,28 @@ namespace TagLib {
 			set {}
 		}
 		
+		/// <summary>
+		///    Gets and sets the sort names of the performers or artists
+		///    who performed in the media described by the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string[]" /> containing the sort names for
+		///    the performers or artists who performed in the media
+		///    described by the current instance, or an empty array if
+		///    no value is present. 
+		/// </value>
+		/// <remarks>
+		///    <para>This is used to provide more control over how tracks
+		///    are sorted. Typical uses are to skip common prefixes or
+		///    sort by last name. For example, "The Beatles" might be
+		///    sorted as "Beatles, The".
+		///    </para>
+		/// </remarks>
+		public virtual string [] PerformersSort {
+			get {return new string [] {};}
+			set {}
+		}
+		
 		/// <summary>
 		///    Gets and sets the band or artist who is credited in the
 		///    creation of the entire album or collection containing the
@@ -203,6 +242,38 @@ namespace TagLib {
 			set {}
 		}
 		
+		/// <summary>
+		///    Gets and sets the sort names for the band or artist who
+		///    is credited in the creation of the entire album or
+		///    collection containing the media described by the
+		///    current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string[]" /> containing the sort names
+		///    for the band or artist who is credited in the creation
+		///    of the entire album or collection containing the media
+		///    described by the current instance or an empty array if
+		///    no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field is typically optional but aids in the
+		///    sorting of compilations or albums with multiple artists.
+		///    For example, if an album has several artists, sorting by
+		///    artist will split up the album and sorting by album will
+		///    split up albums by the same artist. Having a single album
+		///    artist for an entire album will solve this
+		///    problem.</para>
+		///    <para>As this value is to be used as a sorting key, it
+		///    should be used with less variation than <see
+		///    cref="Performers" />. Where performers can be broken into
+		///    muliple artist it is best to stick with a single band
+		///    name. For example, "Beatles, The".</para>
+		/// </remarks>
+		public virtual string [] AlbumArtistsSort {
+			get {return new string [] {};}
+			set {}
+		}
+		
 		/// <summary>
 		///    Gets and sets the composers of the media represented by
 		///    the current instance.
@@ -222,6 +293,30 @@ namespace TagLib {
 			set {}
 		}
 		
+		/// <summary>
+		///    Gets and sets the sort names for the composers of the 
+		///    media represented by the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string[]" /> containing the sort names
+		///    for the composers of the media represented by the 
+		///    current instance or an empty array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field is typically optional but aids in the
+		///    sorting of compilations or albums with multiple Composers.
+		///    </para>
+		///    <para>As this value is to be used as a sorting key, it
+		///    should be used with less variation than <see
+		///    cref="Composers" />. Where performers can be broken into
+		///    muliple artist it is best to stick with a single composer.
+		///    For example, "McCartney, Paul".</para>
+		/// </remarks>
+		public virtual string [] ComposersSort {
+			get {return new string [] {};}
+			set {}
+		}
+		
 		/// <summary>
 		///    Gets and sets the album of the media represented by the
 		///    current instance.
@@ -246,6 +341,25 @@ namespace TagLib {
 			set {}
 		}
 		
+		/// <summary>
+		///    Gets and sets the sort names for the Album Title of the 
+		///    media represented by the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string[]" /> containing the sort names
+		///    for the Album Title of the media represented by the 
+		///    current instance or an empty array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field is typically optional but aids in the
+		///    sorting of compilations or albums with Similar Titles.
+		///    </para>
+		/// </remarks>
+		public virtual string AlbumSort {
+			get {return null;}
+			set {}
+		}
+		
 		/// <summary>
 		///    Gets and sets a user comment on the media represented by
 		///    the current instance.
@@ -496,6 +610,194 @@ namespace TagLib {
 			set {}
 		}
 		
+		/// <summary>
+		///    Gets and sets the MusicBrainz Artist ID of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz ArtistID of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz ArtistID, and is used
+		///    to uniquely identify a particular Artist of the track.</para>
+		/// </remarks>
+		public virtual string MusicBrainzArtistId {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicBrainz Release ID of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz ReleaseID of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz ReleaseID, and is used
+		///    to uniquely identify a particular Release to which this track belongs.</para>
+		/// </remarks>
+		public virtual string MusicBrainzReleaseId {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicBrainz Release Artist ID of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz ReleaseArtistID of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz Release ArtistID, and is used
+		///    to uniquely identify a particular Album Artist credited with the Album.</para>
+		/// </remarks>
+		public virtual string MusicBrainzReleaseArtistId {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicBrainz Track ID of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz TrackID of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz TrackID, and is used
+		///    to uniquely identify a particular track.</para>
+		/// </remarks>
+		public virtual string MusicBrainzTrackId {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicBrainz Disc ID of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz DiscID of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz DiscID, and is used
+		///    to uniquely identify the particular Released Media associated with
+		///    this track.</para>
+		/// </remarks>
+		public virtual string MusicBrainzDiscId {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicIP PUID of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicIP PUID of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicIP PUID, and is an acoustic
+		///    fingerprint identifier.  It Identifies what this track "Sounds Like".</para>
+		/// </remarks>
+		public virtual string MusicIpId {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the Amazon ID of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the AmazonID of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the AmazonID, and is used
+		///    to identify the particular track or album in the Amazon Catalog.</para>
+		/// </remarks>
+		public virtual string AmazonId {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicBrainz Release Status of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz ReleaseStatus of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz ReleaseStatus, and is used
+		///    to describes how 'official' a Release is.  Common Status are: Official, Promotion,
+		///    Bootleg, Pseudo-release.</para>
+		/// </remarks>
+		public virtual string MusicBrainzReleaseStatus {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicBrainz Release Type of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz ReleaseType of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz ReleaseType, that describes
+		///    what kind of release a Release is..  Common Status are: Single, Album,
+		///    EP, Compilation, Soundtrack, SpokenWord, Interview, Audiobook, Live, Remix,
+		///    and Other.  Careful thought must be given when using this field to decide if
+		///    a particular track "Is a Compilation".</para>
+		/// </remarks>
+		public virtual string MusicBrainzReleaseType {
+			get { return null; }
+			set {}
+		}
+
+		/// <summary>
+		///    Gets and sets the MusicBrainz Release Country of the media represented by
+		///    the current instance.
+		/// </summary>
+		/// <value>
+		///    A <see cref="string" /> containing the MusicBrainz ReleaseCountry of the
+		///    media represented by the current instance or an empty
+		///    array if no value is present.
+		/// </value>
+		/// <remarks>
+		///    <para>This field represents the MusicBrainz ReleaseCountry, that describes
+		///    the country in which an album was released.  Note that the ReleaseCountry 
+		///    of an album is not necessarily the country in which it was produced. The 
+		///    label itself will typically be more relevant. eg, a release on "Foo Records UK" 
+		///    that has "Made in Austria" printed on it, will likely be a UK release.</para>
+		/// </remarks>
+		public virtual string MusicBrainzReleaseCountry {
+			get { return null; }
+			set {}
+		}
+
 		/// <summary>
 		///    Gets and sets a collection of pictures associated with
 		///    the media represented by the current instance.
@@ -567,6 +869,23 @@ namespace TagLib {
 			get {return FirstInGroup(AlbumArtists);}
 		}
 		
+		/// <summary>
+		///    Gets the first value contained in <see
+		///    cref="AlbumArtistsSort" />.
+		/// </summary>
+		/// <value>
+		///    The first <see cref="string" /> object in <see
+		///    cref="AlbumArtistsSort" />, or <see langword="null" /> is it
+		///    contains no values.
+		/// </value>
+		/// <remarks>
+		///    This property is provided for convenience. Use <see
+		///    cref="AlbumArtistsSort" /> to set the value.
+		/// </remarks>
+		public string FirstAlbumArtistSort {
+			get {return FirstInGroup(AlbumArtistsSort);}
+		}
+		
 		/// <summary>
 		///    Gets the first value contained in <see
 		///    cref="Performers" />.
@@ -583,6 +902,40 @@ namespace TagLib {
 		public string FirstPerformer {
 			get {return FirstInGroup(Performers);}
 		}
+
+		/// <summary>
+		///    Gets the first value contained in <see
+		///    cref="PerformersSort" />.
+		/// </summary>
+		/// <value>
+		///    The first <see cref="string" /> object in <see
+		///    cref="PerformersSort" />, or <see langword="null" /> is it
+		///    contains no values.
+		/// </value>
+		/// <remarks>
+		///    This property is provided for convenience. Use <see
+		///    cref="PerformersSort" /> to set the value.
+		/// </remarks>
+		public string FirstPerformerSort {
+			get {return FirstInGroup(PerformersSort);}
+		}
+		
+		/// <summary>
+		///    Gets the first value contained in <see
+		///    cref="ComposersSort" />.
+		/// </summary>
+		/// <value>
+		///    The first <see cref="string" /> object in <see
+		///    cref="ComposersSort" />, or <see langword="null" /> is it
+		///    contains no values.
+		/// </value>
+		/// <remarks>
+		///    This property is provided for convenience. Use <see
+		///    cref="ComposersSort" /> to set the value.
+		/// </remarks>
+		public string FirstComposerSort {
+			get {return FirstInGroup(ComposersSort);}
+		}
 		
 		/// <summary>
 		///    Gets the first value contained in <see
@@ -665,6 +1018,22 @@ namespace TagLib {
 			get {return JoinGroup(Performers);}
 		}
 		
+		/// <summary>
+		///    Gets a semicolon separated string containing the values
+		///    in <see cref="PerformersSort" />.
+		/// </summary>
+		/// <value>
+		///    A semicolon separated <see cref="string" /> object
+		///    containing the values in <see cref="PerformersSort" />.
+		/// </value>
+		/// <remarks>
+		///    This property is provided for convenience. Use <see
+		///    cref="PerformersSort" /> to set the value.
+		/// </remarks>
+		public string JoinedPerformersSort {
+			get {return JoinGroup(PerformersSort);}
+		}
+		
 		/// <summary>
 		///    Gets a semicolon separated string containing the values
 		///    in <see cref="Composers" />.
@@ -892,7 +1261,7 @@ namespace TagLib {
 				target.Conductor = Conductor;
 			
 			if (overwrite || IsNullOrLikeEmpty (target.Copyright))
-				target.Conductor = Copyright;
+				target.Copyright = Copyright;
 		}
 		
 		/// <summary>
